<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>HomeDaemon</name>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="55"/>
        <source>Deepin Home</source>
        <translation>深度之家</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="57"/>
        <source>Show main window</source>
        <translation>顯示主視窗</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="64"/>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="296"/>
        <source>View</source>
        <translation>查看</translation>
    </message>
</context>
</TS>